cosinnus.core package
=====================

Subpackages
-----------

.. toctree::

    cosinnus.core.decorators
    cosinnus.core.registries

Submodules
----------

cosinnus.core.mail module
-------------------------

.. automodule:: cosinnus.core.mail
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: cosinnus.core
    :members:
    :undoc-members:
    :show-inheritance:
